//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

#ifndef WSCMESSAGEBOX_H
#define WSCMESSAGEBOX_H

#include <WScom.h>
#include <WSCbaseDialog.h>

class WSCform;
class WSCtextField;

class WSCmessageBox  :public WSCbaseDialog {

  protected:
     WSCform*    _form;
     WSCtextField* _textf;
     char*     _label_string;
     WSCulong     _vvalue;
     WSCulong     _hvalue;

     WSMFpropertyDef( WSNlabelString,  char*,  _label_string ); 
     WSMFpropertyDef( WSNvbarValue, WSCulong,  _vvalue);
     WSMFpropertyDef( WSNhbarValue, WSCulong,  _hvalue);

     
     WSDLEX32 void _adjust();

//virtual void onVisibleChange(WSCbool);
//virtual void onParentVisibleChange(WSCbool);
WSDLEX32 virtual void onResize(WSCrect*);
WSDLEX32 virtual void onActivate();
WSDLEX32 virtual void onGuiPolicyChange(long);

WSDLEX32 static     void _textf_work(WSCbase*);
  public:
    WSDLEX32 WSCmessageBox(WSCbase*,char*);
    WSDLEX32 virtual ~WSCmessageBox();
    WSDLEX32 virtual  long initialize();
    WSDLEX32 virtual WSCbase* getPropertyInheritChild();
    WSCtextField* getTextField();

    WSMFguiClassDef(WSCmessageBox,WSCbaseDialog);
};


#endif
